package ru.ulstu.conference.service;

import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import ru.ulstu.conference.repository.ConferenceUserRepository;
import ru.ulstu.user.model.UserConference;

import java.util.List;
import java.util.stream.Collectors;

@Service
public class ConferenceUserService {

    private final ConferenceUserRepository conferenceUserRepository;

    public ConferenceUserService(ConferenceUserRepository conferenceUserRepository) {
        this.conferenceUserRepository = conferenceUserRepository;
    }

    public List<UserConference> saveOrCreate(List<UserConference> users) {
        return users
                .stream()
                .map(user -> {
                    return user.getId() != null ? update(user) : create(user);
                }).collect(Collectors.toList());
    }

    @Transactional
    public UserConference update(UserConference user) {
        UserConference updateUser = conferenceUserRepository.findOne(user.getId());
        updateUser.setDeposit(user.getDeposit());
        updateUser.setParticipation(user.getParticipation());
        conferenceUserRepository.save(updateUser);
        return updateUser;
    }

    @Transactional
    public UserConference create(UserConference user) {
        UserConference newUser = new UserConference();
        newUser.setDeposit(user.getDeposit());
        newUser.setParticipation(user.getParticipation());
        newUser.setUser(user.getUser());
        newUser = conferenceUserRepository.save(newUser);
        return newUser;
    }


}
